#ifndef __MAPOBJECT_UI_H__
#define __MAPOBJECT_UI_H__

/* Externally visible variables */
/* ============================ */

extern GtkWidget *previewarea;

/* Externally visible functions */
/* ============================ */

gboolean main_dialog (gint32 drawable_id);

#endif  /* __MAPOBJECT_UI_H__ */
